summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/codegenerationpolicy.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:37:49 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:37:49 -0600
commitf8069e2ea048f2657cc417d83820576ec55c181b (patch)
treecbc5bf540866934a91e0f33b260fc7a25e191fad /umbrello/umbrello/codegenerationpolicy.h
parente6aaa3624cc6179b82a9bfff1760e742a669064c (diff)
downloadtdesdk-f8069e2ea048f2657cc417d83820576ec55c181b.tar.gz
tdesdk-f8069e2ea048f2657cc417d83820576ec55c181b.zip
Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid conflicts with KDE4
Diffstat (limited to 'umbrello/umbrello/codegenerationpolicy.h')
-rw-r--r--umbrello/umbrello/codegenerationpolicy.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/umbrello/umbrello/codegenerationpolicy.h b/umbrello/umbrello/codegenerationpolicy.h
index 146299c2..3d065dee 100644
--- a/umbrello/umbrello/codegenerationpolicy.h
+++ b/umbrello/umbrello/codegenerationpolicy.h
@@ -24,7 +24,7 @@
#include <tqdom.h>
class TQWidget;
-class KConfig;
+class TDEConfig;
class CodeGenerationPolicyPage;
/**
@@ -79,7 +79,7 @@ public:
// note that as the code gen policy may be the 'default' policy, it may
// not be coupled with a code generator.
CodeGenerationPolicy (CodeGenerationPolicy * clone = 0);
- CodeGenerationPolicy (KConfig * config );
+ CodeGenerationPolicy (TDEConfig * config );
/**
* Empty Destructor
@@ -315,14 +315,14 @@ public:
virtual void setDefaults (CodeGenerationPolicy * defaults, bool emitUpdateSignal = true);
/**
* set the defaults from a config file for this code generator from the passed KConfig pointer.
*/
- virtual void setDefaults(KConfig * config, bool emitUpdateSignal = true);
+ virtual void setDefaults(TDEConfig * config, bool emitUpdateSignal = true);
/**
* write Default params to passed KConfig pointer.
*/
- virtual void writeConfig (KConfig * config);
+ virtual void writeConfig (TDEConfig * config);
void emitModifiedCodeContentSig();
@@ -315,14 +315,14 @@ public:
virtual void setDefaults (CodeGenerationPolicy * defaults, bool emitUpdateSignal = true);
/**
- * set the defaults from a config file for this code generator from the passed KConfig pointer.
+ * set the defaults from a config file for this code generator from the passed TDEConfig pointer.
*/
@@ -315,14 +315,14 @@ public:
/**
- * write Default params to passed KConfig pointer.
+ * write Default params to passed TDEConfig pointer.
*/